Class: Aws::MWAA::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MWAA::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mwaa/client.rb,
sig/client.rbs
Overview
An API client for MWAA. To construct a client, you need to configure a :region and :credentials.
client = Aws::MWAA::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateCliTokenResponseSuccess, _CreateEnvironmentResponseSuccess, _CreateWebLoginTokenResponseSuccess, _DeleteEnvironmentResponseSuccess, _GetEnvironmentResponseSuccess, _InvokeRestApiResponseSuccess, _ListEnvironmentsResponseSuccess, _ListTagsForResourceResponseSuccess, _PublishMetricsResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateEnvironmentResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_cli_token(params = {}) ⇒ Types::CreateCliTokenResponse
Creates a CLI token for the Airflow CLI.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentOutput
Creates an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
-
#create_web_login_token(params = {}) ⇒ Types::CreateWebLoginTokenResponse
Creates a web login token for the Airflow Web UI.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentOutput
Describes an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#invoke_rest_api(params = {}) ⇒ Types::InvokeRestApiResponse
Invokes the Apache Airflow REST API on the webserver with the specified inputs.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsOutput
Lists the Amazon Managed Workflows for Apache Airflow (MWAA) environments.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the key-value tag pairs associated to the Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#publish_metrics(params = {}) ⇒ Struct
Internal only.
-
#tag_resource(params = {}) ⇒ Struct
Associates key-value tag pairs to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#untag_resource(params = {}) ⇒ Struct
Removes key-value tag pairs associated to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentOutput
Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mwaa/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1604 1605 1606 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1604 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1607 1608 1609 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1607 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1577 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MWAA') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mwaa' context[:gem_version] = '1.78.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cli_token(params = {}) ⇒ Types::CreateCliTokenResponse
Creates a CLI token for the Airflow CLI. To learn more, see Creating an Apache Airflow CLI token.
87 |
# File 'sig/client.rbs', line 87
def create_cli_token: (
|
#create_environment(params = {}) ⇒ Types::CreateEnvironmentOutput
Creates an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
97 |
# File 'sig/client.rbs', line 97
def create_environment: (
|
#create_web_login_token(params = {}) ⇒ Types::CreateWebLoginTokenResponse
Creates a web login token for the Airflow Web UI. To learn more, see Creating an Apache Airflow web login token.
137 |
# File 'sig/client.rbs', line 137
def create_web_login_token: (
|
#delete_environment(params = {}) ⇒ Struct
Deletes an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
146 |
# File 'sig/client.rbs', line 146
def delete_environment: (
|
#get_environment(params = {}) ⇒ Types::GetEnvironmentOutput
Describes an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
156 |
# File 'sig/client.rbs', line 156
def get_environment: (
|
#invoke_rest_api(params = {}) ⇒ Types::InvokeRestApiResponse
Invokes the Apache Airflow REST API on the webserver with the specified inputs. To learn more, see Using the Apache Airflow REST API
167 |
# File 'sig/client.rbs', line 167
def invoke_rest_api: (
|
#list_environments(params = {}) ⇒ Types::ListEnvironmentsOutput
Lists the Amazon Managed Workflows for Apache Airflow (MWAA) environments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
184 |
# File 'sig/client.rbs', line 184
def list_environments: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the key-value tag pairs associated to the Amazon Managed
Workflows for Apache Airflow (MWAA) environment. For example,
"Environment": "Staging".
195 |
# File 'sig/client.rbs', line 195
def list_tags_for_resource: (
|
#publish_metrics(params = {}) ⇒ Struct
Internal only. Publishes environment health metrics to Amazon CloudWatch.
204 |
# File 'sig/client.rbs', line 204
def publish_metrics: (
|
#tag_resource(params = {}) ⇒ Struct
Associates key-value tag pairs to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
233 |
# File 'sig/client.rbs', line 233
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes key-value tag pairs associated to your Amazon Managed
Workflows for Apache Airflow (MWAA) environment. For example,
"Environment": "Staging".
243 |
# File 'sig/client.rbs', line 243
def untag_resource: (
|
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentOutput
Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
254 |
# File 'sig/client.rbs', line 254
def update_environment: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1597 1598 1599 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1597 def waiter_names [] end |