Class: Aws::MWAA::Types::LastUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAA::Types::LastUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaa/types.rb
Overview
Describes the status of the last update on the environment, and any errors that were encountered.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The day and time of the last update on the environment.
-
#error ⇒ Types::UpdateError
The error that was encountered during the last update of the environment.
-
#source ⇒ String
The source of the last update to the environment.
-
#status ⇒ String
The status of the last update on the environment.
-
#worker_replacement_strategy ⇒ String
The worker replacement strategy used in the last update of the environment.
Instance Attribute Details
#created_at ⇒ Time
The day and time of the last update on the environment.
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-mwaa/types.rb', line 1027 class LastUpdate < Struct.new( :status, :created_at, :error, :source, :worker_replacement_strategy) SENSITIVE = [] include Aws::Structure end |
#error ⇒ Types::UpdateError
The error that was encountered during the last update of the environment.
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-mwaa/types.rb', line 1027 class LastUpdate < Struct.new( :status, :created_at, :error, :source, :worker_replacement_strategy) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source of the last update to the environment. Includes internal processes by Amazon MWAA, such as an environment maintenance update.
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-mwaa/types.rb', line 1027 class LastUpdate < Struct.new( :status, :created_at, :error, :source, :worker_replacement_strategy) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the last update on the environment.
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-mwaa/types.rb', line 1027 class LastUpdate < Struct.new( :status, :created_at, :error, :source, :worker_replacement_strategy) SENSITIVE = [] include Aws::Structure end |
#worker_replacement_strategy ⇒ String
The worker replacement strategy used in the last update of the environment.
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-mwaa/types.rb', line 1027 class LastUpdate < Struct.new( :status, :created_at, :error, :source, :worker_replacement_strategy) SENSITIVE = [] include Aws::Structure end |