Class: Aws::MWAA::Types::UpdateNetworkConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAA::Types::UpdateNetworkConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaa/types.rb
Overview
Defines the VPC networking components used to secure and enable network traffic between the Amazon Web Services resources for your environment. For more information, refer to About networking on Amazon MWAA.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_group_ids ⇒ Array<String>
A list of security group IDs.
Instance Attribute Details
#security_group_ids ⇒ Array<String>
A list of security group IDs. A security group must be attached to the same VPC as the subnets. For more information, refer to Security in your VPC on Amazon MWAA.
1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-mwaa/types.rb', line 1843 class UpdateNetworkConfigurationInput < Struct.new( :security_group_ids) SENSITIVE = [] include Aws::Structure end |