Class: Aws::MWAA::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MWAA::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mwaa/client.rb
Overview
An API client for MWAA. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MWAA::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_cli_token(params = {}) ⇒ Types::CreateCliTokenResponse
Creates a CLI token for the Airflow CLI.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentOutput
Creates an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
-
#create_web_login_token(params = {}) ⇒ Types::CreateWebLoginTokenResponse
Creates a web login token for the Airflow Web UI.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentOutput
Describes an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#invoke_rest_api(params = {}) ⇒ Types::InvokeRestApiResponse
Invokes the Apache Airflow REST API on the webserver with the specified inputs.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsOutput
Lists the Amazon Managed Workflows for Apache Airflow (MWAA) environments.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the key-value tag pairs associated to the Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#publish_metrics(params = {}) ⇒ Struct
**Internal only**.
-
#tag_resource(params = {}) ⇒ Struct
Associates key-value tag pairs to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#untag_resource(params = {}) ⇒ Struct
Removes key-value tag pairs associated to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentOutput
Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mwaa/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1604 1605 1606 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1604 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1607 1608 1609 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1607 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1577 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MWAA') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mwaa' context[:gem_version] = '1.76.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cli_token(params = {}) ⇒ Types::CreateCliTokenResponse
Creates a CLI token for the Airflow CLI. To learn more, see [Creating an Apache Airflow CLI token].
[1]: docs.aws.amazon.com/mwaa/latest/userguide/call-mwaa-apis-cli.html
508 509 510 511 |
# File 'lib/aws-sdk-mwaa/client.rb', line 508 def create_cli_token(params = {}, = {}) req = build_request(:create_cli_token, params) req.send_request() end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentOutput
Creates an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
843 844 845 846 |
# File 'lib/aws-sdk-mwaa/client.rb', line 843 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#create_web_login_token(params = {}) ⇒ Types::CreateWebLoginTokenResponse
Creates a web login token for the Airflow Web UI. To learn more, see [Creating an Apache Airflow web login token].
[1]: docs.aws.amazon.com/mwaa/latest/userguide/call-mwaa-apis-web.html
883 884 885 886 |
# File 'lib/aws-sdk-mwaa/client.rb', line 883 def create_web_login_token(params = {}, = {}) req = build_request(:create_web_login_token, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Struct
Deletes an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
907 908 909 910 |
# File 'lib/aws-sdk-mwaa/client.rb', line 907 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#get_environment(params = {}) ⇒ Types::GetEnvironmentOutput
Describes an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
994 995 996 997 |
# File 'lib/aws-sdk-mwaa/client.rb', line 994 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |
#invoke_rest_api(params = {}) ⇒ Types::InvokeRestApiResponse
Invokes the Apache Airflow REST API on the webserver with the specified inputs. To learn more, see [Using the Apache Airflow REST API]
[1]: docs.aws.amazon.com/mwaa/latest/userguide/access-mwaa-apache-airflow-rest-api.html
1067 1068 1069 1070 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1067 def invoke_rest_api(params = {}, = {}) req = build_request(:invoke_rest_api, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsOutput
Lists the Amazon Managed Workflows for Apache Airflow (MWAA) environments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1106 1107 1108 1109 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1106 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the key-value tag pairs associated to the Amazon Managed Workflows for Apache Airflow (MWAA) environment. For example, ‘“Environment”: “Staging”`.
1139 1140 1141 1142 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1139 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#publish_metrics(params = {}) ⇒ Struct
**Internal only**. Publishes environment health metrics to Amazon CloudWatch.
1191 1192 1193 1194 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1191 def publish_metrics(params = {}, = {}) req = build_request(:publish_metrics, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates key-value tag pairs to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
1228 1229 1230 1231 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1228 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes key-value tag pairs associated to your Amazon Managed Workflows for Apache Airflow (MWAA) environment. For example, ‘“Environment”: “Staging”`.
1259 1260 1261 1262 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1259 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentOutput
Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
1568 1569 1570 1571 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1568 def update_environment(params = {}, = {}) req = build_request(:update_environment, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1597 1598 1599 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1597 def waiter_names [] end |