Class: Aws::MWAA::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MWAA::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mwaa/client.rb
Overview
An API client for MWAA. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MWAA::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_cli_token(params = {}) ⇒ Types::CreateCliTokenResponse
Creates a CLI token for the Airflow CLI.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentOutput
Creates an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
-
#create_web_login_token(params = {}) ⇒ Types::CreateWebLoginTokenResponse
Creates a web login token for the Airflow Web UI.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentOutput
Describes an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#invoke_rest_api(params = {}) ⇒ Types::InvokeRestApiResponse
Invokes the Apache Airflow REST API on the webserver with the specified inputs.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsOutput
Lists the Amazon Managed Workflows for Apache Airflow (MWAA) environments.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the key-value tag pairs associated to the Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#publish_metrics(params = {}) ⇒ Struct
**Internal only**.
-
#tag_resource(params = {}) ⇒ Struct
Associates key-value tag pairs to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#untag_resource(params = {}) ⇒ Struct
Removes key-value tag pairs associated to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
-
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentOutput
Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-mwaa/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1594 1595 1596 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1594 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1597 1598 1599 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1597 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1567 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MWAA') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mwaa' context[:gem_version] = '1.69.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cli_token(params = {}) ⇒ Types::CreateCliTokenResponse
Creates a CLI token for the Airflow CLI. To learn more, see [Creating an Apache Airflow CLI token].
[1]: docs.aws.amazon.com/mwaa/latest/userguide/call-mwaa-apis-cli.html
510 511 512 513 |
# File 'lib/aws-sdk-mwaa/client.rb', line 510 def create_cli_token(params = {}, = {}) req = build_request(:create_cli_token, params) req.send_request() end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentOutput
Creates an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
840 841 842 843 |
# File 'lib/aws-sdk-mwaa/client.rb', line 840 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#create_web_login_token(params = {}) ⇒ Types::CreateWebLoginTokenResponse
Creates a web login token for the Airflow Web UI. To learn more, see [Creating an Apache Airflow web login token].
[1]: docs.aws.amazon.com/mwaa/latest/userguide/call-mwaa-apis-web.html
880 881 882 883 |
# File 'lib/aws-sdk-mwaa/client.rb', line 880 def create_web_login_token(params = {}, = {}) req = build_request(:create_web_login_token, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Struct
Deletes an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
904 905 906 907 |
# File 'lib/aws-sdk-mwaa/client.rb', line 904 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#get_environment(params = {}) ⇒ Types::GetEnvironmentOutput
Describes an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
991 992 993 994 |
# File 'lib/aws-sdk-mwaa/client.rb', line 991 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |
#invoke_rest_api(params = {}) ⇒ Types::InvokeRestApiResponse
Invokes the Apache Airflow REST API on the webserver with the specified inputs. To learn more, see [Using the Apache Airflow REST API]
[1]: docs.aws.amazon.com/mwaa/latest/userguide/access-mwaa-apache-airflow-rest-api.html
1064 1065 1066 1067 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1064 def invoke_rest_api(params = {}, = {}) req = build_request(:invoke_rest_api, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsOutput
Lists the Amazon Managed Workflows for Apache Airflow (MWAA) environments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1103 1104 1105 1106 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1103 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the key-value tag pairs associated to the Amazon Managed Workflows for Apache Airflow (MWAA) environment. For example, ‘“Environment”: “Staging”`.
1136 1137 1138 1139 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1136 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#publish_metrics(params = {}) ⇒ Struct
**Internal only**. Publishes environment health metrics to Amazon CloudWatch.
1188 1189 1190 1191 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1188 def publish_metrics(params = {}, = {}) req = build_request(:publish_metrics, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates key-value tag pairs to your Amazon Managed Workflows for Apache Airflow (MWAA) environment.
1225 1226 1227 1228 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1225 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes key-value tag pairs associated to your Amazon Managed Workflows for Apache Airflow (MWAA) environment. For example, ‘“Environment”: “Staging”`.
1256 1257 1258 1259 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1256 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentOutput
Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.
1558 1559 1560 1561 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1558 def update_environment(params = {}, = {}) req = build_request(:update_environment, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1587 1588 1589 |
# File 'lib/aws-sdk-mwaa/client.rb', line 1587 def waiter_names [] end |