Method: Aws::MWAA::Types::CreateEnvironmentInput#endpoint_management
- Defined in:
- lib/aws-sdk-mwaa/types.rb
#endpoint_management ⇒ String
Defines whether the VPC endpoints configured for the environment are created, and managed, by the customer or by Amazon MWAA. If set to SERVICE, Amazon MWAA will create and manage the required VPC endpoints in your VPC. If set to CUSTOMER, you must create, and manage, the VPC endpoints for your VPC. If you choose to create an environment in a shared VPC, you must set this value to CUSTOMER. In a shared VPC deployment, the environment will remain in PENDING status until you create the VPC endpoints. If you do not take action to create the endpoints within 72 hours, the status will change to CREATE_FAILED. You can delete the failed environment and create a new one.
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-mwaa/types.rb', line 352 class CreateEnvironmentInput < Struct.new( :name, :execution_role_arn, :source_bucket_arn, :dag_s3_path, :network_configuration, :plugins_s3_path, :plugins_s3_object_version, :requirements_s3_path, :requirements_s3_object_version, :startup_script_s3_path, :startup_script_s3_object_version, :airflow_configuration_options, :environment_class, :max_workers, :kms_key, :airflow_version, :logging_configuration, :weekly_maintenance_window_start, :tags, :webserver_access_mode, :min_workers, :schedulers, :endpoint_management, :min_webservers, :max_webservers) SENSITIVE = [:airflow_configuration_options] include Aws::Structure end |